==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/win_control.h <==
 /*
 * file      : win_control.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __win_control_h__
#define __win_control_h__ 1


void       wincontrol_remove (void);
void       wincontrol_set_adr (GtkWidget *Adr_win, gchar *NameWin, gboolean bool_transient, gboolean bool_modal);
void       wincontrol_remove_last (void);
void       wincontrol_remove_with_name (gchar *p_NameWin);
GtkWidget *wincontrol_get_last_adr (void);
GtkWidget *wincontrol_get_adr_with_name (gchar *p_NameWin);


#endif

==> xcfa_3.7.3.orig.tar.gz: xcfa-3.7.3/src/win_control.h <==
 /*
 * file      : win_control.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __win_control_h__
#define __win_control_h__ 1

#define WIND_USE_STRUCT		TRUE
#define WIND_NOT_USE_STRUCT	FALSE

#define WIND_IS_MODAL		TRUE
#define WIND_IS_NOT_MODAL	FALSE
#define WIND_IS_TRANSIENT	TRUE
#define WIND_IS_NOT_TRANSIENT	FALSE
#define WIND_IS_SHOW		TRUE
#define WIND_IS_NOT_SHOW	FALSE


void       wincontrol_remove (void);
void       wincontrol_remove_with_name (gchar *p_NameWin);
GtkWidget *wincontrol_get_last_adr (void);
GtkWidget *wincontrol_get_adr_with_name (gchar *p_NameWin);

void       wincontrol_remove_last (void);
void       wincontrol_set_adr (GtkWidget *Adr_win, gchar *NameWin, gboolean bool_transient, gboolean bool_modal);

void       NEW_wincontrol_remove_last (void);
void       NEW_wincontrol_realize_window (GtkWidget	**p_AdrWidgetWindow,	// Adresse flag
					  gchar		*p_NameWidgetWindow,	// Nom de la fenetre dans le fichier xml
					  gboolean	*p_Bool_Is_Hide,	// Adresse flag
					  gboolean	 p_ShowWindow,		// WIND_IS_SHOW | WIND_IS_NOT_SHOW
					  gboolean	 p_UseStruct,		// WIND_USE_STRUCT | WIND_NOT_USE_STRUCT
					  gboolean	 p_Modal,		// WIND_IS_MODAL | WIND_IS_NOT_MODAL
					  gboolean	 p_Transient);		// WIND_IS_TRANSIENT | WIND_IS_NOT_TRANSIENT

#endif
